ziggy.GraphReduce.gr_path

Package ziggy :: Package GraphReduce :: Module gr_path |
[hide private]
[frames] | no frames]

# Module gr_path

source code

Created on Aug 12, 2010

Author: dwmclary

Functions | [hide private]
connected_components(G, name=None, recompute=False) | source code
num_connected_components(G, name=None, recompute=False) | source code
single_source_shortest_path(G, source, target=None, name=None, recompute=False) | source code
single_source_shortest_path_length(G, source, target=None, name=None, recompute=False) | source code
single_source_average_shortest_path_length(G, source, target=None, name=None, recompute=False) | source code
shortest_path(G, source=None, target=None, name=None, recompute=False) | source code
shortest_path_length(G, source=None, target=None, name=None, recompute=False) | source code
average_shortest_path_length(G, name=None, recompute=False) | source code
average_out_degree(G, name=None) | source code
average_in_degree(G, name=None) | source code
average_degree(G, name=None) | source code
out_degree(G, name=None) | source code
in_degree(G, name=None) | source code
degree(G, name=None) | source code
bfs(G, source, name=None) | source code
parallel_degree(hdfs_handle) | source code
parallel_bfs(source, hdfs_handle, old_inf_count) | source code
fetch_sp_from_hdfs(hdfs_handle, source) | source code
fetch_degree_from_hdfs(hdfs_handle) | source code
check_for_precomputed_degree_result(G, name) | source code
check_for_precomputed_bfs_result(G, name, source) | source code

Variables | [hide private]
| __author__ = ``'``D. McClary (dan.mcclary@northwestern.edu)``'``
| __package__ = ``'``ziggy.GraphReduce``'``